# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/atlas/editorial_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/atlas/editorial_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.atlas import editorial_pb2 as eolymp_dot_atlas_dot_editorial__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/atlas/editorial_service.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1c\x65olymp/atlas/editorial.proto\"\x83\x01\n\x13ListEditorialsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0f\n\x07version\x18\x64 \x01(\r\x12\x0e\n\x06render\x18\x01 \x01(\x08\x12-\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1d.eolymp.atlas.Editorial.Extra\"M\n\x14ListEditorialsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.atlas.Editorial\"~\n\x16\x44\x65scribeEditorialInput\x12\x14\n\x0c\x65\x64itorial_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\x12\x0e\n\x06render\x18\x03 \x01(\x08\x12-\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1d.eolymp.atlas.Editorial.Extra\"E\n\x17\x44\x65scribeEditorialOutput\x12*\n\teditorial\x18\x01 \x01(\x0b\x32\x17.eolymp.atlas.Editorial\"v\n\x14LookupEditorialInput\x12\x0e\n\x06locale\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\x12\x0e\n\x06render\x18\x03 \x01(\x08\x12-\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1d.eolymp.atlas.Editorial.Extra\"C\n\x15LookupEditorialOutput\x12*\n\teditorial\x18\x01 \x01(\x0b\x32\x17.eolymp.atlas.Editorial\"C\n\x15PreviewEditorialInput\x12*\n\teditorial\x18\x02 \x01(\x0b\x32\x17.eolymp.atlas.Editorial\"D\n\x16PreviewEditorialOutput\x12*\n\teditorial\x18\x01 \x01(\x0b\x32\x17.eolymp.atlas.Editorial\"B\n\x14\x43reateEditorialInput\x12*\n\teditorial\x18\x02 \x01(\x0b\x32\x17.eolymp.atlas.Editorial\"-\n\x15\x43reateEditorialOutput\x12\x14\n\x0c\x65\x64itorial_id\x18\x01 \x01(\t\"\x86\x01\n\x14UpdateEditorialInput\x12,\n\x05patch\x18\n \x03(\x0e\x32\x1d.eolymp.atlas.Editorial.Patch\x12\x14\n\x0c\x65\x64itorial_id\x18\x02 \x01(\t\x12*\n\teditorial\x18\x03 \x01(\x0b\x32\x17.eolymp.atlas.Editorial\"\x17\n\x15UpdateEditorialOutput\",\n\x14\x44\x65leteEditorialInput\x12\x14\n\x0c\x65\x64itorial_id\x18\x02 \x01(\t\"\x17\n\x15\x44\x65leteEditorialOutput\"m\n\x18TranslateEditorialsInput\x12\x0e\n\x06source\x18\x01 \x01(\t\x12\x0e\n\x06target\x18\x02 \x03(\t\x12\x18\n\x10target_automatic\x18\x03 \x01(\x08\x12\x17\n\x0foverride_manual\x18\x04 \x01(\x08\"+\n\x19TranslateEditorialsOutput\x12\x0e\n\x06job_id\x18\x01 \x01(\t2\xbd\n\n\x10\x45\x64itorialService\x12\x99\x01\n\x0f\x43reateEditorial\x12\".eolymp.atlas.CreateEditorialInput\x1a#.eolymp.atlas.CreateEditorialOutput\"=\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\r\x1a\x0b/editorials\x12\xa8\x01\n\x0fUpdateEditorial\x12\".eolymp.atlas.UpdateEditorialInput\x1a#.eolymp.atlas.UpdateEditorialOutput\"L\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x1c\x1a\x1a/editorials/{editorial_id}\x12\xa8\x01\n\x0f\x44\x65leteEditorial\x12\".eolymp.atlas.DeleteEditorialInput\x1a#.eolymp.atlas.DeleteEditorialOutput\"L\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x1c*\x1a/editorials/{editorial_id}\x12\xad\x01\n\x11\x44\x65scribeEditorial\x12$.eolymp.atlas.DescribeEditorialInput\x1a%.eolymp.atlas.DescribeEditorialOutput\"K\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\x82\xd3\xe4\x93\x02\x1c\x12\x1a/editorials/{editorial_id}\x12\x97\x01\n\x0fLookupEditorial\x12\".eolymp.atlas.LookupEditorialInput\x1a#.eolymp.atlas.LookupEditorialOutput\";\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\x82\xd3\xe4\x93\x02\x0c\x12\n/editorial\x12\xa2\x01\n\x10PreviewEditorial\x12#.eolymp.atlas.PreviewEditorialInput\x1a$.eolymp.atlas.PreviewEditorialOutput\"C\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\x82\xd3\xe4\x93\x02\x14\"\x12/editorial/preview\x12\x95\x01\n\x0eListEditorials\x12!.eolymp.atlas.ListEditorialsInput\x1a\".eolymp.atlas.ListEditorialsOutput\"<\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\x82\xd3\xe4\x93\x02\r\x12\x0b/editorials\x12\xaf\x01\n\x13TranslateEditorials\x12&.eolymp.atlas.TranslateEditorialsInput\x1a\'.eolymp.atlas.TranslateEditorialsOutput\"G\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x17\"\x15/editorials:translateB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.editorial_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _globals['_EDITORIALSERVICE'].methods_by_name['CreateEditorial']._loaded_options = None
  _globals['_EDITORIALSERVICE'].methods_by_name['CreateEditorial']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\r\032\013/editorials'
  _globals['_EDITORIALSERVICE'].methods_by_name['UpdateEditorial']._loaded_options = None
  _globals['_EDITORIALSERVICE'].methods_by_name['UpdateEditorial']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\034\032\032/editorials/{editorial_id}'
  _globals['_EDITORIALSERVICE'].methods_by_name['DeleteEditorial']._loaded_options = None
  _globals['_EDITORIALSERVICE'].methods_by_name['DeleteEditorial']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\034*\032/editorials/{editorial_id}'
  _globals['_EDITORIALSERVICE'].methods_by_name['DescribeEditorial']._loaded_options = None
  _globals['_EDITORIALSERVICE'].methods_by_name['DescribeEditorial']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022atlas:problem:read\202\323\344\223\002\034\022\032/editorials/{editorial_id}'
  _globals['_EDITORIALSERVICE'].methods_by_name['LookupEditorial']._loaded_options = None
  _globals['_EDITORIALSERVICE'].methods_by_name['LookupEditorial']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022atlas:problem:read\202\323\344\223\002\014\022\n/editorial'
  _globals['_EDITORIALSERVICE'].methods_by_name['PreviewEditorial']._loaded_options = None
  _globals['_EDITORIALSERVICE'].methods_by_name['PreviewEditorial']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022atlas:problem:read\202\323\344\223\002\024\"\022/editorial/preview'
  _globals['_EDITORIALSERVICE'].methods_by_name['ListEditorials']._loaded_options = None
  _globals['_EDITORIALSERVICE'].methods_by_name['ListEditorials']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022atlas:problem:read\202\323\344\223\002\r\022\013/editorials'
  _globals['_EDITORIALSERVICE'].methods_by_name['TranslateEditorials']._loaded_options = None
  _globals['_EDITORIALSERVICE'].methods_by_name['TranslateEditorials']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\027\"\025/editorials:translate'
  _globals['_LISTEDITORIALSINPUT']._serialized_start=184
  _globals['_LISTEDITORIALSINPUT']._serialized_end=315
  _globals['_LISTEDITORIALSOUTPUT']._serialized_start=317
  _globals['_LISTEDITORIALSOUTPUT']._serialized_end=394
  _globals['_DESCRIBEEDITORIALINPUT']._serialized_start=396
  _globals['_DESCRIBEEDITORIALINPUT']._serialized_end=522
  _globals['_DESCRIBEEDITORIALOUTPUT']._serialized_start=524
  _globals['_DESCRIBEEDITORIALOUTPUT']._serialized_end=593
  _globals['_LOOKUPEDITORIALINPUT']._serialized_start=595
  _globals['_LOOKUPEDITORIALINPUT']._serialized_end=713
  _globals['_LOOKUPEDITORIALOUTPUT']._serialized_start=715
  _globals['_LOOKUPEDITORIALOUTPUT']._serialized_end=782
  _globals['_PREVIEWEDITORIALINPUT']._serialized_start=784
  _globals['_PREVIEWEDITORIALINPUT']._serialized_end=851
  _globals['_PREVIEWEDITORIALOUTPUT']._serialized_start=853
  _globals['_PREVIEWEDITORIALOUTPUT']._serialized_end=921
  _globals['_CREATEEDITORIALINPUT']._serialized_start=923
  _globals['_CREATEEDITORIALINPUT']._serialized_end=989
  _globals['_CREATEEDITORIALOUTPUT']._serialized_start=991
  _globals['_CREATEEDITORIALOUTPUT']._serialized_end=1036
  _globals['_UPDATEEDITORIALINPUT']._serialized_start=1039
  _globals['_UPDATEEDITORIALINPUT']._serialized_end=1173
  _globals['_UPDATEEDITORIALOUTPUT']._serialized_start=1175
  _globals['_UPDATEEDITORIALOUTPUT']._serialized_end=1198
  _globals['_DELETEEDITORIALINPUT']._serialized_start=1200
  _globals['_DELETEEDITORIALINPUT']._serialized_end=1244
  _globals['_DELETEEDITORIALOUTPUT']._serialized_start=1246
  _globals['_DELETEEDITORIALOUTPUT']._serialized_end=1269
  _globals['_TRANSLATEEDITORIALSINPUT']._serialized_start=1271
  _globals['_TRANSLATEEDITORIALSINPUT']._serialized_end=1380
  _globals['_TRANSLATEEDITORIALSOUTPUT']._serialized_start=1382
  _globals['_TRANSLATEEDITORIALSOUTPUT']._serialized_end=1425
  _globals['_EDITORIALSERVICE']._serialized_start=1428
  _globals['_EDITORIALSERVICE']._serialized_end=2769
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/community/rating_point.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/community/rating_point.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#eolymp/community/rating_point.proto\x12\x10\x65olymp.community\x1a\x1fgoogle/protobuf/timestamp.proto\"y\n\x0bRatingPoint\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03ref\x18\x02 \x01(\t\x12-\n\ttimestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05value\x18\n \x01(\r\x12\x13\n\x0btarget_link\x18\x14 \x01(\tB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.rating_point_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _globals['_RATINGPOINT']._serialized_start=90
  _globals['_RATINGPOINT']._serialized_end=211
# @@protoc_insertion_point(module_scope)



from eolymp.ecm import content_pb2 as _content_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Variant(_message.Message):
    __slots__ = ("id", "locale", "title", "content", "automatic")
    class Extra(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        NO_EXTRA: _ClassVar[Variant.Extra]
        CONTENT_RENDER: _ClassVar[Variant.Extra]
        CONTENT_VALUE: _ClassVar[Variant.Extra]
    NO_EXTRA: Variant.Extra
    CONTENT_RENDER: Variant.Extra
    CONTENT_VALUE: Variant.Extra
    ID_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    AUTOMATIC_FIELD_NUMBER: _ClassVar[int]
    id: str
    locale: str
    title: str
    content: _content_pb2.Content
    automatic: bool
    def __init__(self, id: _Optional[str] = ..., locale: _Optional[str] = ..., title: _Optional[str] = ..., content: _Optional[_Union[_content_pb2.Content, _Mapping]] = ..., automatic: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/reward/achievement.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/reward/achievement.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x65olymp/reward/achievement.proto\x12\reolymp.reward\x1a\x18\x65olymp/ecm/content.proto\"\xac\x02\n\x0b\x41\x63hievement\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\r\x12\x0e\n\x06rarity\x18\x03 \x01(\r\x12\x0c\n\x04name\x18\n \x01(\t\x12\x11\n\timage_url\x18\x0c \x01(\t\x12$\n\x07summary\x18\x0b \x01(\x0b\x32\x13.eolymp.ecm.Content\x12\x0e\n\x06\x63ursor\x18\x64 \x01(\t\x1a]\n\x0bTranslation\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18\x66 \x01(\t\x12\x0c\n\x04name\x18g \x01(\t\x12$\n\x07summary\x18h \x01(\x0b\x32\x13.eolymp.ecm.Content\"<\n\x05\x45xtra\x12\x0c\n\x08NO_EXTRA\x10\x00\x12\x11\n\rSUMMARY_VALUE\x10\x01\x12\x12\n\x0eSUMMARY_RENDER\x10\x02\x42/Z-github.com/eolymp/go-sdk/eolymp/reward;rewardb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.reward.achievement_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/reward;reward'
  _globals['_ACHIEVEMENT']._serialized_start=77
  _globals['_ACHIEVEMENT']._serialized_end=377
  _globals['_ACHIEVEMENT_TRANSLATION']._serialized_start=222
  _globals['_ACHIEVEMENT_TRANSLATION']._serialized_end=315
  _globals['_ACHIEVEMENT_EXTRA']._serialized_start=317
  _globals['_ACHIEVEMENT_EXTRA']._serialized_end=377
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/course/course_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/course/course_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.course import course_pb2 as eolymp_dot_course_dot_course__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/course/course_service.proto\x12\reolymp.course\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1a\x65olymp/course/course.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\"\xbe\x03\n\x10ListCoursesInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0e\n\x06search\x18\x14 \x01(\t\x12\x37\n\x07\x66ilters\x18( \x01(\x0b\x32&.eolymp.course.ListCoursesInput.Filter\x12\x36\n\x04sort\x18\x32 \x01(\x0e\x32(.eolymp.course.ListCoursesInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12+\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1b.eolymp.course.Course.Extra\x1a\x98\x01\n\x06\x46ilter\x12*\n\x02id\x18\n \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x08topic_id\x18\x0b \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x06locale\x18\x0c \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"\x17\n\x08Sortable\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\"H\n\x11ListCoursesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12$\n\x05items\x18\x02 \x03(\x0b\x32\x15.eolymp.course.Course\"U\n\x13\x44\x65scribeCourseInput\x12\x11\n\tcourse_id\x18\x01 \x01(\t\x12+\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1b.eolymp.course.Course.Extra\"=\n\x14\x44\x65scribeCourseOutput\x12%\n\x06\x63ourse\x18\x01 \x01(\x0b\x32\x15.eolymp.course.Course\":\n\x11\x43reateCourseInput\x12%\n\x06\x63ourse\x18\x01 \x01(\x0b\x32\x15.eolymp.course.Course\"\'\n\x12\x43reateCourseOutput\x12\x11\n\tcourse_id\x18\x01 \x01(\t\"\xf2\x01\n\x11UpdateCourseInput\x12\x35\n\x05patch\x18\x01 \x03(\x0e\x32&.eolymp.course.UpdateCourseInput.Patch\x12\x11\n\tcourse_id\x18\x02 \x01(\t\x12%\n\x06\x63ourse\x18\x03 \x01(\x0b\x32\x15.eolymp.course.Course\"l\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\n\n\x06LOCALE\x10\x01\x12\x08\n\x04NAME\x10\x02\x12\x0f\n\x0b\x44\x45SCRIPTION\x10\x03\x12\t\n\x05IMAGE\x10\x04\x12\x0e\n\nVISIBILITY\x10\x05\x12\x0c\n\x08\x44URATION\x10\x06\x12\n\n\x06TOPICS\x10\x07\"\x14\n\x12UpdateCourseOutput\"&\n\x11\x44\x65leteCourseInput\x12\x11\n\tcourse_id\x18\x01 \x01(\t\"\x14\n\x12\x44\x65leteCourseOutput\"\xc0\x01\n\x0f\x43opyCourseInput\x12\x11\n\tcourse_id\x18\x01 \x01(\t\x12\x38\n\ncopy_scope\x18\x02 \x03(\x0e\x32$.eolymp.course.CopyCourseInput.Scope\x12\x11\n\tcopy_name\x18\x03 \x01(\t\"M\n\x05Scope\x12\x07\n\x03\x41LL\x10\x00\x12\x0b\n\x07MODULES\x10\x01\x12\x0c\n\x08STUDENTS\x10\x02\x12\x0f\n\x0b\x41SSIGNMENTS\x10\x03\x12\x0f\n\x0bPERMISSIONS\x10\x04\"*\n\x10\x43opyCourseOutput\x12\x16\n\x0e\x63opy_course_id\x18\x01 \x01(\t2\xab\x07\n\rCourseService\x12\x8f\x01\n\x0c\x43reateCourse\x12 .eolymp.course.CreateCourseInput\x1a!.eolymp.course.CreateCourseOutput\":\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\x82\xd3\xe4\x93\x02\n\x1a\x08/courses\x12\x9b\x01\n\x0cUpdateCourse\x12 .eolymp.course.UpdateCourseInput\x1a!.eolymp.course.UpdateCourseOutput\"F\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\x82\xd3\xe4\x93\x02\x16\x1a\x14/courses/{course_id}\x12\x9b\x01\n\x0c\x44\x65leteCourse\x12 .eolymp.course.DeleteCourseInput\x1a!.eolymp.course.DeleteCourseOutput\"F\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\x82\xd3\xe4\x93\x02\x16*\x14/courses/{course_id}\x12\xa0\x01\n\x0e\x44\x65scribeCourse\x12\".eolymp.course.DescribeCourseInput\x1a#.eolymp.course.DescribeCourseOutput\"E\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\x82\xd3\xe4\x93\x02\x16\x12\x14/courses/{course_id}\x12\x8b\x01\n\x0bListCourses\x12\x1f.eolymp.course.ListCoursesInput\x1a .eolymp.course.ListCoursesOutput\"9\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\x82\xd3\xe4\x93\x02\n\x12\x08/courses\x12\x9a\x01\n\nCopyCourse\x12\x1e.eolymp.course.CopyCourseInput\x1a\x1f.eolymp.course.CopyCourseOutput\"K\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\x82\xd3\xe4\x93\x02\x1b\"\x19/courses/{course_id}/copyB/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.course_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _globals['_COURSESERVICE'].methods_by_name['CreateCourse']._loaded_options = None
  _globals['_COURSESERVICE'].methods_by_name['CreateCourse']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023course:course:write\202\323\344\223\002\n\032\010/courses'
  _globals['_COURSESERVICE'].methods_by_name['UpdateCourse']._loaded_options = None
  _globals['_COURSESERVICE'].methods_by_name['UpdateCourse']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023course:course:write\202\323\344\223\002\026\032\024/courses/{course_id}'
  _globals['_COURSESERVICE'].methods_by_name['DeleteCourse']._loaded_options = None
  _globals['_COURSESERVICE'].methods_by_name['DeleteCourse']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023course:course:write\202\323\344\223\002\026*\024/courses/{course_id}'
  _globals['_COURSESERVICE'].methods_by_name['DescribeCourse']._loaded_options = None
  _globals['_COURSESERVICE'].methods_by_name['DescribeCourse']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022course:course:read\202\323\344\223\002\026\022\024/courses/{course_id}'
  _globals['_COURSESERVICE'].methods_by_name['ListCourses']._loaded_options = None
  _globals['_COURSESERVICE'].methods_by_name['ListCourses']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022course:course:read\202\323\344\223\002\n\022\010/courses'
  _globals['_COURSESERVICE'].methods_by_name['CopyCourse']._loaded_options = None
  _globals['_COURSESERVICE'].methods_by_name['CopyCourse']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023course:course:write\202\323\344\223\002\033\"\031/courses/{course_id}/copy'
  _globals['_LISTCOURSESINPUT']._serialized_start=250
  _globals['_LISTCOURSESINPUT']._serialized_end=696
  _globals['_LISTCOURSESINPUT_FILTER']._serialized_start=519
  _globals['_LISTCOURSESINPUT_FILTER']._serialized_end=671
  _globals['_LISTCOURSESINPUT_SORTABLE']._serialized_start=673
  _globals['_LISTCOURSESINPUT_SORTABLE']._serialized_end=696
  _globals['_LISTCOURSESOUTPUT']._serialized_start=698
  _globals['_LISTCOURSESOUTPUT']._serialized_end=770
  _globals['_DESCRIBECOURSEINPUT']._serialized_start=772
  _globals['_DESCRIBECOURSEINPUT']._serialized_end=857
  _globals['_DESCRIBECOURSEOUTPUT']._serialized_start=859
  _globals['_DESCRIBECOURSEOUTPUT']._serialized_end=920
  _globals['_CREATECOURSEINPUT']._serialized_start=922
  _globals['_CREATECOURSEINPUT']._serialized_end=980
  _globals['_CREATECOURSEOUTPUT']._serialized_start=982
  _globals['_CREATECOURSEOUTPUT']._serialized_end=1021
  _globals['_UPDATECOURSEINPUT']._serialized_start=1024
  _globals['_UPDATECOURSEINPUT']._serialized_end=1266
  _globals['_UPDATECOURSEINPUT_PATCH']._serialized_start=1158
  _globals['_UPDATECOURSEINPUT_PATCH']._serialized_end=1266
  _globals['_UPDATECOURSEOUTPUT']._serialized_start=1268
  _globals['_UPDATECOURSEOUTPUT']._serialized_end=1288
  _globals['_DELETECOURSEINPUT']._serialized_start=1290
  _globals['_DELETECOURSEINPUT']._serialized_end=1328
  _globals['_DELETECOURSEOUTPUT']._serialized_start=1330
  _globals['_DELETECOURSEOUTPUT']._serialized_end=1350
  _globals['_COPYCOURSEINPUT']._serialized_start=1353
  _globals['_COPYCOURSEINPUT']._serialized_end=1545
  _globals['_COPYCOURSEINPUT_SCOPE']._serialized_start=1468
  _globals['_COPYCOURSEINPUT_SCOPE']._serialized_end=1545
  _globals['_COPYCOURSEOUTPUT']._serialized_start=1547
  _globals['_COPYCOURSEOUTPUT']._serialized_end=1589
  _globals['_COURSESERVICE']._serialized_start=1592
  _globals['_COURSESERVICE']._serialized_end=2531
# @@protoc_insertion_point(module_scope)



from eolymp.executor import checker_pb2 as _checker_pb2
from eolymp.executor import script_pb2 as _script_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EvaluationTask(_message.Message):
    __slots__ = ("task_id", "reference", "origin", "metadata", "priority", "redirect_stderr_to_stdout", "time_coefficient_deviation", "run_count", "interactive_followup", "preconditions", "constraints", "submission", "interactor", "checker", "scripts", "runs")
    class DependencyMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_DEPENDENCY_MODE: _ClassVar[EvaluationTask.DependencyMode]
        FULLY_ACCEPTED: _ClassVar[EvaluationTask.DependencyMode]
        FIRST_POINT: _ClassVar[EvaluationTask.DependencyMode]
    UNKNOWN_DEPENDENCY_MODE: EvaluationTask.DependencyMode
    FULLY_ACCEPTED: EvaluationTask.DependencyMode
    FIRST_POINT: EvaluationTask.DependencyMode
    class Generator(_message.Message):
        __slots__ = ("script_name", "arguments")
        SCRIPT_NAME_FIELD_NUMBER: _ClassVar[int]
        ARGUMENTS_FIELD_NUMBER: _ClassVar[int]
        script_name: str
        arguments: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, script_name: _Optional[str] = ..., arguments: _Optional[_Iterable[str]] = ...) -> None: ...
    class Run(_message.Message):
        __slots__ = ("reference", "index", "group", "debug", "cost", "env", "labels", "input_url", "input_content", "input_generator", "answer_url", "answer_content", "answer_generator")
        class EnvEntry(_message.Message):
            __slots__ = ("key", "value")
            KEY_FIELD_NUMBER: _ClassVar[int]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            key: str
            value: str
            def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
        REFERENCE_FIELD_NUMBER: _ClassVar[int]
        INDEX_FIELD_NUMBER: _ClassVar[int]
        GROUP_FIELD_NUMBER: _ClassVar[int]
        DEBUG_FIELD_NUMBER: _ClassVar[int]
        COST_FIELD_NUMBER: _ClassVar[int]
        ENV_FIELD_NUMBER: _ClassVar[int]
        LABELS_FIELD_NUMBER: _ClassVar[int]
        INPUT_URL_FIELD_NUMBER: _ClassVar[int]
        INPUT_CONTENT_FIELD_NUMBER: _ClassVar[int]
        INPUT_GENERATOR_FIELD_NUMBER: _ClassVar[int]
        ANSWER_URL_FIELD_NUMBER: _ClassVar[int]
        ANSWER_CONTENT_FIELD_NUMBER: _ClassVar[int]
        ANSWER_GENERATOR_FIELD_NUMBER: _ClassVar[int]
        reference: str
        index: int
        group: int
        debug: bool
        cost: float
        env: _containers.ScalarMap[str, str]
        labels: _containers.RepeatedScalarFieldContainer[str]
        input_url: str
        input_content: str
        input_generator: EvaluationTask.Generator
        answer_url: str
        answer_content: str
        answer_generator: EvaluationTask.Generator
        def __init__(self, reference: _Optional[str] = ..., index: _Optional[int] = ..., group: _Optional[int] = ..., debug: bool = ..., cost: _Optional[float] = ..., env: _Optional[_Mapping[str, str]] = ..., labels: _Optional[_Iterable[str]] = ..., input_url: _Optional[str] = ..., input_content: _Optional[str] = ..., input_generator: _Optional[_Union[EvaluationTask.Generator, _Mapping]] = ..., answer_url: _Optional[str] = ..., answer_content: _Optional[str] = ..., answer_generator: _Optional[_Union[EvaluationTask.Generator, _Mapping]] = ...) -> None: ...
    class Precondition(_message.Message):
        __slots__ = ("selector", "depends_on", "dependency_mode", "stop_on_failure", "max_execution_time")
        SELECTOR_FIELD_NUMBER: _ClassVar[int]
        DEPENDS_ON_FIELD_NUMBER: _ClassVar[int]
        DEPENDENCY_MODE_FIELD_NUMBER: _ClassVar[int]
        STOP_ON_FAILURE_FIELD_NUMBER: _ClassVar[int]
        MAX_EXECUTION_TIME_FIELD_NUMBER: _ClassVar[int]
        selector: _containers.RepeatedScalarFieldContainer[str]
        depends_on: _containers.RepeatedScalarFieldContainer[str]
        dependency_mode: EvaluationTask.DependencyMode
        stop_on_failure: bool
        max_execution_time: int
        def __init__(self, selector: _Optional[_Iterable[str]] = ..., depends_on: _Optional[_Iterable[str]] = ..., dependency_mode: _Optional[_Union[EvaluationTask.DependencyMode, str]] = ..., stop_on_failure: bool = ..., max_execution_time: _Optional[int] = ...) -> None: ...
    class Constraint(_message.Message):
        __slots__ = ("selector", "actor", "wall_time_limit", "cpu_time_limit", "memory_limit", "file_size_limit")
        SELECTOR_FIELD_NUMBER: _ClassVar[int]
        ACTOR_FIELD_NUMBER: _ClassVar[int]
        WALL_TIME_LIMIT_FIELD_NUMBER: _ClassVar[int]
        CPU_TIME_LIMIT_FIELD_NUMBER: _ClassVar[int]
        MEMORY_LIMIT_FIELD_NUMBER: _ClassVar[int]
        FILE_SIZE_LIMIT_FIELD_NUMBER: _ClassVar[int]
        selector: _containers.RepeatedScalarFieldContainer[str]
        actor: str
        wall_time_limit: int
        cpu_time_limit: int
        memory_limit: int
        file_size_limit: int
        def __init__(self, selector: _Optional[_Iterable[str]] = ..., actor: _Optional[str] = ..., wall_time_limit: _Optional[int] = ..., cpu_time_limit: _Optional[int] = ..., memory_limit: _Optional[int] = ..., file_size_limit: _Optional[int] = ...) -> None: ...
    class MetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_FIELD_NUMBER: _ClassVar[int]
    ORIGIN_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    PRIORITY_FIELD_NUMBER: _ClassVar[int]
    REDIRECT_STDERR_TO_STDOUT_FIELD_NUMBER: _ClassVar[int]
    TIME_COEFFICIENT_DEVIATION_FIELD_NUMBER: _ClassVar[int]
    RUN_COUNT_FIELD_NUMBER: _ClassVar[int]
    INTERACTIVE_FOLLOWUP_FIELD_NUMBER: _ClassVar[int]
    PRECONDITIONS_FIELD_NUMBER: _ClassVar[int]
    CONSTRAINTS_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_FIELD_NUMBER: _ClassVar[int]
    INTERACTOR_FIELD_NUMBER: _ClassVar[int]
    CHECKER_FIELD_NUMBER: _ClassVar[int]
    SCRIPTS_FIELD_NUMBER: _ClassVar[int]
    RUNS_FIELD_NUMBER: _ClassVar[int]
    task_id: str
    reference: str
    origin: str
    metadata: _containers.ScalarMap[str, str]
    priority: int
    redirect_stderr_to_stdout: bool
    time_coefficient_deviation: float
    run_count: int
    interactive_followup: bool
    preconditions: _containers.RepeatedCompositeFieldContainer[EvaluationTask.Precondition]
    constraints: _containers.RepeatedCompositeFieldContainer[EvaluationTask.Constraint]
    submission: _script_pb2.Script
    interactor: _script_pb2.Script
    checker: _checker_pb2.Checker
    scripts: _containers.RepeatedCompositeFieldContainer[_script_pb2.Script]
    runs: _containers.RepeatedCompositeFieldContainer[EvaluationTask.Run]
    def __init__(self, task_id: _Optional[str] = ..., reference: _Optional[str] = ..., origin: _Optional[str] = ..., metadata: _Optional[_Mapping[str, str]] = ..., priority: _Optional[int] = ..., redirect_stderr_to_stdout: bool = ..., time_coefficient_deviation: _Optional[float] = ..., run_count: _Optional[int] = ..., interactive_followup: bool = ..., preconditions: _Optional[_Iterable[_Union[EvaluationTask.Precondition, _Mapping]]] = ..., constraints: _Optional[_Iterable[_Union[EvaluationTask.Constraint, _Mapping]]] = ..., submission: _Optional[_Union[_script_pb2.Script, _Mapping]] = ..., interactor: _Optional[_Union[_script_pb2.Script, _Mapping]] = ..., checker: _Optional[_Union[_checker_pb2.Checker, _Mapping]] = ..., scripts: _Optional[_Iterable[_Union[_script_pb2.Script, _Mapping]]] = ..., runs: _Optional[_Iterable[_Union[EvaluationTask.Run, _Mapping]]] = ...) -> None: ...



import datetime

from eolymp.ranker import format_pb2 as _format_pb2
from eolymp.wellknown import direction_pb2 as _direction_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Scoreboard(_message.Message):
    __slots__ = ("id", "key", "name", "historical", "frozen", "freeze_at", "unfreeze_at", "default_sort_column", "default_sort_order", "format", "contests")
    class Extra(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_EXTRA: _ClassVar[Scoreboard.Extra]
        CONTESTS: _ClassVar[Scoreboard.Extra]
    UNKNOWN_EXTRA: Scoreboard.Extra
    CONTESTS: Scoreboard.Extra
    class FetchingMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        LATEST: _ClassVar[Scoreboard.FetchingMode]
        PUNCTUAL: _ClassVar[Scoreboard.FetchingMode]
        FROZEN: _ClassVar[Scoreboard.FetchingMode]
        UPSOLVE: _ClassVar[Scoreboard.FetchingMode]
    LATEST: Scoreboard.FetchingMode
    PUNCTUAL: Scoreboard.FetchingMode
    FROZEN: Scoreboard.FetchingMode
    UPSOLVE: Scoreboard.FetchingMode
    class Row(_message.Message):
        __slots__ = ("id", "name", "member_id", "score", "penalty", "ghost", "unofficial", "rank", "rank_lower", "values")
        class Value(_message.Message):
            __slots__ = ("id", "column_id", "valid_after", "valid_until", "score", "penalty", "percentage", "attempts", "solved_in", "upsolve", "value_string", "value_number")
            ID_FIELD_NUMBER: _ClassVar[int]
            COLUMN_ID_FIELD_NUMBER: _ClassVar[int]
            VALID_AFTER_FIELD_NUMBER: _ClassVar[int]
            VALID_UNTIL_FIELD_NUMBER: _ClassVar[int]
            SCORE_FIELD_NUMBER: _ClassVar[int]
            PENALTY_FIELD_NUMBER: _ClassVar[int]
            PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
            ATTEMPTS_FIELD_NUMBER: _ClassVar[int]
            SOLVED_IN_FIELD_NUMBER: _ClassVar[int]
            UPSOLVE_FIELD_NUMBER: _ClassVar[int]
            VALUE_STRING_FIELD_NUMBER: _ClassVar[int]
            VALUE_NUMBER_FIELD_NUMBER: _ClassVar[int]
            id: str
            column_id: str
            valid_after: int
            valid_until: int
            score: float
            penalty: float
            percentage: float
            attempts: int
            solved_in: int
            upsolve: bool
            value_string: str
            value_number: int
            def __init__(self, id: _Optional[str] = ..., column_id: _Optional[str] = ..., valid_after: _Optional[int] = ..., valid_until: _Optional[int] = ..., score: _Optional[float] = ..., penalty: _Optional[float] = ..., percentage: _Optional[float] = ..., attempts: _Optional[int] = ..., solved_in: _Optional[int] = ..., upsolve: bool = ..., value_string: _Optional[str] = ..., value_number: _Optional[int] = ...) -> None: ...
        ID_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
        SCORE_FIELD_NUMBER: _ClassVar[int]
        PENALTY_FIELD_NUMBER: _ClassVar[int]
        GHOST_FIELD_NUMBER: _ClassVar[int]
        UNOFFICIAL_FIELD_NUMBER: _ClassVar[int]
        RANK_FIELD_NUMBER: _ClassVar[int]
        RANK_LOWER_FIELD_NUMBER: _ClassVar[int]
        VALUES_FIELD_NUMBER: _ClassVar[int]
        id: str
        name: str
        member_id: str
        score: float
        penalty: float
        ghost: bool
        unofficial: bool
        rank: int
        rank_lower: int
        values: _containers.RepeatedCompositeFieldContainer[Scoreboard.Row.Value]
        def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., member_id: _Optional[str] = ..., score: _Optional[float] = ..., penalty: _Optional[float] = ..., ghost: bool = ..., unofficial: bool = ..., rank: _Optional[int] = ..., rank_lower: _Optional[int] = ..., values: _Optional[_Iterable[_Union[Scoreboard.Row.Value, _Mapping]]] = ...) -> None: ...
    class Column(_message.Message):
        __slots__ = ("id", "parent_id", "key", "name", "short_name", "type", "index", "visible", "filterable", "sortable", "judge_contest_id", "judge_problem_id", "community_attribute_key", "community_attribute_type")
        class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            NONE: _ClassVar[Scoreboard.Column.Type]
            CONTEST: _ClassVar[Scoreboard.Column.Type]
            PROBLEM: _ClassVar[Scoreboard.Column.Type]
            ATTRIBUTE: _ClassVar[Scoreboard.Column.Type]
            NAME: _ClassVar[Scoreboard.Column.Type]
            TOTAL: _ClassVar[Scoreboard.Column.Type]
        NONE: Scoreboard.Column.Type
        CONTEST: Scoreboard.Column.Type
        PROBLEM: Scoreboard.Column.Type
        ATTRIBUTE: Scoreboard.Column.Type
        NAME: Scoreboard.Column.Type
        TOTAL: Scoreboard.Column.Type
        ID_FIELD_NUMBER: _ClassVar[int]
        PARENT_ID_FIELD_NUMBER: _ClassVar[int]
        KEY_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        SHORT_NAME_FIELD_NUMBER: _ClassVar[int]
        TYPE_FIELD_NUMBER: _ClassVar[int]
        INDEX_FIELD_NUMBER: _ClassVar[int]
        VISIBLE_FIELD_NUMBER: _ClassVar[int]
        FILTERABLE_FIELD_NUMBER: _ClassVar[int]
        SORTABLE_FIELD_NUMBER: _ClassVar[int]
        JUDGE_CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
        JUDGE_PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
        COMMUNITY_ATTRIBUTE_KEY_FIELD_NUMBER: _ClassVar[int]
        COMMUNITY_ATTRIBUTE_TYPE_FIELD_NUMBER: _ClassVar[int]
        id: str
        parent_id: str
        key: str
        name: str
        short_name: str
        type: Scoreboard.Column.Type
        index: int
        visible: bool
        filterable: bool
        sortable: bool
        judge_contest_id: str
        judge_problem_id: str
        community_attribute_key: str
        community_attribute_type: str
        def __init__(self, id: _Optional[str] = ..., parent_id: _Optional[str] = ..., key: _Optional[str] = ..., name: _Optional[str] = ..., short_name: _Optional[str] = ..., type: _Optional[_Union[Scoreboard.Column.Type, str]] = ..., index: _Optional[int] = ..., visible: bool = ..., filterable: bool = ..., sortable: bool = ..., judge_contest_id: _Optional[str] = ..., judge_problem_id: _Optional[str] = ..., community_attribute_key: _Optional[str] = ..., community_attribute_type: _Optional[str] = ...) -> None: ...
    class Action(_message.Message):
        __slots__ = ("id", "execute_at", "type")
        class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            NONE: _ClassVar[Scoreboard.Action.Type]
            FREEZE: _ClassVar[Scoreboard.Action.Type]
            UNFREEZE: _ClassVar[Scoreboard.Action.Type]
        NONE: Scoreboard.Action.Type
        FREEZE: Scoreboard.Action.Type
        UNFREEZE: Scoreboard.Action.Type
        ID_FIELD_NUMBER: _ClassVar[int]
        EXECUTE_AT_FIELD_NUMBER: _ClassVar[int]
        TYPE_FIELD_NUMBER: _ClassVar[int]
        id: str
        execute_at: _timestamp_pb2.Timestamp
        type: Scoreboard.Action.Type
        def __init__(self, id: _Optional[str] = ..., execute_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., type: _Optional[_Union[Scoreboard.Action.Type, str]] = ...) -> None: ...
    class Contest(_message.Message):
        __slots__ = ("id", "name", "image_url", "start_at", "end_at", "status")
        ID_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        IMAGE_URL_FIELD_NUMBER: _ClassVar[int]
        START_AT_FIELD_NUMBER: _ClassVar[int]
        END_AT_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        id: str
        name: str
        image_url: str
        start_at: _timestamp_pb2.Timestamp
        end_at: _timestamp_pb2.Timestamp
        status: str
        def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., image_url: _Optional[str] = ..., start_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., end_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., status: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    HISTORICAL_FIELD_NUMBER: _ClassVar[int]
    FROZEN_FIELD_NUMBER: _ClassVar[int]
    FREEZE_AT_FIELD_NUMBER: _ClassVar[int]
    UNFREEZE_AT_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_SORT_COLUMN_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_SORT_ORDER_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    CONTESTS_FIELD_NUMBER: _ClassVar[int]
    id: str
    key: str
    name: str
    historical: bool
    frozen: bool
    freeze_at: _timestamp_pb2.Timestamp
    unfreeze_at: _timestamp_pb2.Timestamp
    default_sort_column: str
    default_sort_order: _direction_pb2.Direction
    format: _format_pb2.Format
    contests: _containers.RepeatedCompositeFieldContainer[Scoreboard.Contest]
    def __init__(self, id: _Optional[str] = ..., key: _Optional[str] = ..., name: _Optional[str] = ..., historical: bool = ..., frozen: bool = ..., freeze_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., unfreeze_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., default_sort_column: _Optional[str] = ..., default_sort_order: _Optional[_Union[_direction_pb2.Direction, str]] = ..., format: _Optional[_Union[_format_pb2.Format, str]] = ..., contests: _Optional[_Iterable[_Union[Scoreboard.Contest, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/newsletter/recipient.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/newsletter/recipient.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!eolymp/newsletter/recipient.proto\x12\x11\x65olymp.newsletter\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa0\x04\n\tRecipient\x12\n\n\x02id\x18\x01 \x01(\t\x12.\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07sent_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x64\x65livered_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tmember_id\x18\x02 \x01(\t\x12\x33\n\x06status\x18\x03 \x01(\x0e\x32#.eolymp.newsletter.Recipient.Status\x12\x15\n\rstatus_reason\x18\x04 \x01(\t\x12@\n\nparameters\x18\x05 \x03(\x0b\x32,.eolymp.newsletter.Recipient.ParametersEntry\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"t\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\x08\n\x04SENT\x10\x03\x12\r\n\tDELIVERED\x10\x04\x12\x0b\n\x07\x42OUNCED\x10\x05\x12\x0b\n\x07SKIPPED\x10\x06\x12\t\n\x05\x45RROR\x10\x07\x42\x37Z5github.com/eolymp/go-sdk/eolymp/newsletter;newsletterb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.newsletter.recipient_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/newsletter;newsletter'
  _globals['_RECIPIENT_PARAMETERSENTRY']._loaded_options = None
  _globals['_RECIPIENT_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_RECIPIENT']._serialized_start=90
  _globals['_RECIPIENT']._serialized_end=634
  _globals['_RECIPIENT_PARAMETERSENTRY']._serialized_start=467
  _globals['_RECIPIENT_PARAMETERSENTRY']._serialized_end=516
  _globals['_RECIPIENT_STATUS']._serialized_start=518
  _globals['_RECIPIENT_STATUS']._serialized_end=634
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/annotations/endpoint.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/annotations/endpoint.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!eolymp/annotations/endpoint.proto\x12\neolymp.api\x1a google/protobuf/descriptor.proto\"a\n\x08\x45ndpoint\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12-\n\x07service\x18\x02 \x03(\x0b\x32\x1c.eolymp.api.Endpoint.Service\x1a\x17\n\x07Service\x12\x0c\n\x04name\x18\x01 \x01(\t:I\n\x08\x65ndpoint\x12\x1f.google.protobuf.MessageOptions\x18\xbb\xac\x01 \x01(\x0b\x32\x14.eolymp.api.EndpointB9Z7github.com/eolymp/go-sdk/eolymp/annotations;annotationsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.annotations.endpoint_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/eolymp/go-sdk/eolymp/annotations;annotations'
  _globals['_ENDPOINT']._serialized_start=83
  _globals['_ENDPOINT']._serialized_end=180
  _globals['_ENDPOINT_SERVICE']._serialized_start=157
  _globals['_ENDPOINT_SERVICE']._serialized_end=180
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class Medal(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    NO_MEDAL: _ClassVar[Medal]
    GOLD_MEDAL: _ClassVar[Medal]
    SILVER_MEDAL: _ClassVar[Medal]
    BRONZE_MEDAL: _ClassVar[Medal]
    HONORABLE_MENTION: _ClassVar[Medal]
NO_MEDAL: Medal
GOLD_MEDAL: Medal
SILVER_MEDAL: Medal
BRONZE_MEDAL: Medal
HONORABLE_MENTION: Medal



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/commerce/shopping_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/commerce/shopping_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.commerce import address_pb2 as eolymp_dot_commerce_dot_address__pb2
from eolymp.commerce import shopping_cart_pb2 as eolymp_dot_commerce_dot_shopping__cart__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&eolymp/commerce/shopping_service.proto\x12\x0f\x65olymp.commerce\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1d\x65olymp/commerce/address.proto\x1a#eolymp/commerce/shopping_cart.proto\"\x1b\n\x19\x44\x65scribeShoppingCartInput\"I\n\x1a\x44\x65scribeShoppingCartOutput\x12+\n\x04\x63\x61rt\x18\x01 \x01(\x0b\x32\x1d.eolymp.commerce.ShoppingCart\"W\n\x1b\x43reateShoppingCartItemInput\x12\x12\n\nproduct_id\x18\x01 \x01(\t\x12\x12\n\nvariant_id\x18\x02 \x01(\t\x12\x10\n\x08quantity\x18\x03 \x01(\x05\"/\n\x1c\x43reateShoppingCartItemOutput\x12\x0f\n\x07item_id\x18\x01 \x01(\t\"@\n\x1bUpdateShoppingCartItemInput\x12\x0f\n\x07item_id\x18\x01 \x01(\t\x12\x10\n\x08quantity\x18\x02 \x01(\x05\"\x1e\n\x1cUpdateShoppingCartItemOutput\".\n\x1b\x44\x65leteShoppingCartItemInput\x12\x0f\n\x07item_id\x18\x01 \x01(\t\"\x1e\n\x1c\x44\x65leteShoppingCartItemOutput\"G\n\x1aUpdateShippingAddressInput\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x18.eolymp.commerce.Address\"\x1d\n\x1bUpdateShippingAddressOutput\"`\n\x19UpdateBillingAddressInput\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x18.eolymp.commerce.Address\x12\x18\n\x10same_as_shipping\x18\x02 \x01(\x08\"\x1c\n\x1aUpdateBillingAddressOutput\"\x11\n\x0fPlaceOrderInput\":\n\x10PlaceOrderOutput\x12\x10\n\x08order_id\x18\x01 \x01(\t\x12\x14\n\x0corder_number\x18\x02 \x01(\t2\xc7\n\n\x0fShoppingService\x12\xb1\x01\n\x14\x44\x65scribeShoppingCart\x12*.eolymp.commerce.DescribeShoppingCartInput\x1a+.eolymp.commerce.DescribeShoppingCartOutput\"@\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommerce:shopping:read\x82\xd3\xe4\x93\x02\r\x12\x0b/store/cart\x12\xbe\x01\n\x16\x43reateShoppingCartItem\x12,.eolymp.commerce.CreateShoppingCartItemInput\x1a-.eolymp.commerce.CreateShoppingCartItemOutput\"G\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xe3\n\x1b\x8a\xe3\n\x17\x63ommerce:shopping:write\x82\xd3\xe4\x93\x02\x13\"\x11/store/cart/items\x12\xc8\x01\n\x16UpdateShoppingCartItem\x12,.eolymp.commerce.UpdateShoppingCartItemInput\x1a-.eolymp.commerce.UpdateShoppingCartItemOutput\"Q\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xe3\n\x1b\x8a\xe3\n\x17\x63ommerce:shopping:write\x82\xd3\xe4\x93\x02\x1d\x1a\x1b/store/cart/items/{item_id}\x12\xc8\x01\n\x16\x44\x65leteShoppingCartItem\x12,.eolymp.commerce.DeleteShoppingCartItemInput\x1a-.eolymp.commerce.DeleteShoppingCartItemOutput\"Q\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xe3\n\x1b\x8a\xe3\n\x17\x63ommerce:shopping:write\x82\xd3\xe4\x93\x02\x1d*\x1b/store/cart/items/{item_id}\x12\xc6\x01\n\x15UpdateShippingAddress\x12+.eolymp.commerce.UpdateShippingAddressInput\x1a,.eolymp.commerce.UpdateShippingAddressOutput\"R\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xe3\n\x1b\x8a\xe3\n\x17\x63ommerce:shopping:write\x82\xd3\xe4\x93\x02\x1e\"\x1c/store/cart/shipping-address\x12\xc2\x01\n\x14UpdateBillingAddress\x12*.eolymp.commerce.UpdateBillingAddressInput\x1a+.eolymp.commerce.UpdateBillingAddressOutput\"Q\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xe3\n\x1b\x8a\xe3\n\x17\x63ommerce:shopping:write\x82\xd3\xe4\x93\x02\x1d\"\x1b/store/cart/billing-address\x12\x9a\x01\n\nPlaceOrder\x12 .eolymp.commerce.PlaceOrderInput\x1a!.eolymp.commerce.PlaceOrderOutput\"G\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xe3\n\x1b\x8a\xe3\n\x17\x63ommerce:shopping:write\x82\xd3\xe4\x93\x02\x13\"\x11/store/cart:orderB3Z1github.com/eolymp/go-sdk/eolymp/commerce;commerceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.commerce.shopping_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/commerce;commerce'
  _globals['_SHOPPINGSERVICE'].methods_by_name['DescribeShoppingCart']._loaded_options = None
  _globals['_SHOPPINGSERVICE'].methods_by_name['DescribeShoppingCart']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\032\212\343\n\026commerce:shopping:read\202\323\344\223\002\r\022\013/store/cart'
  _globals['_SHOPPINGSERVICE'].methods_by_name['CreateShoppingCartItem']._loaded_options = None
  _globals['_SHOPPINGSERVICE'].methods_by_name['CreateShoppingCartItem']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\343\n\033\212\343\n\027commerce:shopping:write\202\323\344\223\002\023\"\021/store/cart/items'
  _globals['_SHOPPINGSERVICE'].methods_by_name['UpdateShoppingCartItem']._loaded_options = None
  _globals['_SHOPPINGSERVICE'].methods_by_name['UpdateShoppingCartItem']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\343\n\033\212\343\n\027commerce:shopping:write\202\323\344\223\002\035\032\033/store/cart/items/{item_id}'
  _globals['_SHOPPINGSERVICE'].methods_by_name['DeleteShoppingCartItem']._loaded_options = None
  _globals['_SHOPPINGSERVICE'].methods_by_name['DeleteShoppingCartItem']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\343\n\033\212\343\n\027commerce:shopping:write\202\323\344\223\002\035*\033/store/cart/items/{item_id}'
  _globals['_SHOPPINGSERVICE'].methods_by_name['UpdateShippingAddress']._loaded_options = None
  _globals['_SHOPPINGSERVICE'].methods_by_name['UpdateShippingAddress']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\343\n\033\212\343\n\027commerce:shopping:write\202\323\344\223\002\036\"\034/store/cart/shipping-address'
  _globals['_SHOPPINGSERVICE'].methods_by_name['UpdateBillingAddress']._loaded_options = None
  _globals['_SHOPPINGSERVICE'].methods_by_name['UpdateBillingAddress']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\343\n\033\212\343\n\027commerce:shopping:write\202\323\344\223\002\035\"\033/store/cart/billing-address'
  _globals['_SHOPPINGSERVICE'].methods_by_name['PlaceOrder']._loaded_options = None
  _globals['_SHOPPINGSERVICE'].methods_by_name['PlaceOrder']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\343\n\033\212\343\n\027commerce:shopping:write\202\323\344\223\002\023\"\021/store/cart:order'
  _globals['_DESCRIBESHOPPINGCARTINPUT']._serialized_start=226
  _globals['_DESCRIBESHOPPINGCARTINPUT']._serialized_end=253
  _globals['_DESCRIBESHOPPINGCARTOUTPUT']._serialized_start=255
  _globals['_DESCRIBESHOPPINGCARTOUTPUT']._serialized_end=328
  _globals['_CREATESHOPPINGCARTITEMINPUT']._serialized_start=330
  _globals['_CREATESHOPPINGCARTITEMINPUT']._serialized_end=417
  _globals['_CREATESHOPPINGCARTITEMOUTPUT']._serialized_start=419
  _globals['_CREATESHOPPINGCARTITEMOUTPUT']._serialized_end=466
  _globals['_UPDATESHOPPINGCARTITEMINPUT']._serialized_start=468
  _globals['_UPDATESHOPPINGCARTITEMINPUT']._serialized_end=532
  _globals['_UPDATESHOPPINGCARTITEMOUTPUT']._serialized_start=534
  _globals['_UPDATESHOPPINGCARTITEMOUTPUT']._serialized_end=564
  _globals['_DELETESHOPPINGCARTITEMINPUT']._serialized_start=566
  _globals['_DELETESHOPPINGCARTITEMINPUT']._serialized_end=612
  _globals['_DELETESHOPPINGCARTITEMOUTPUT']._serialized_start=614
  _globals['_DELETESHOPPINGCARTITEMOUTPUT']._serialized_end=644
  _globals['_UPDATESHIPPINGADDRESSINPUT']._serialized_start=646
  _globals['_UPDATESHIPPINGADDRESSINPUT']._serialized_end=717
  _globals['_UPDATESHIPPINGADDRESSOUTPUT']._serialized_start=719
  _globals['_UPDATESHIPPINGADDRESSOUTPUT']._serialized_end=748
  _globals['_UPDATEBILLINGADDRESSINPUT']._serialized_start=750
  _globals['_UPDATEBILLINGADDRESSINPUT']._serialized_end=846
  _globals['_UPDATEBILLINGADDRESSOUTPUT']._serialized_start=848
  _globals['_UPDATEBILLINGADDRESSOUTPUT']._serialized_end=876
  _globals['_PLACEORDERINPUT']._serialized_start=878
  _globals['_PLACEORDERINPUT']._serialized_end=895
  _globals['_PLACEORDEROUTPUT']._serialized_start=897
  _globals['_PLACEORDEROUTPUT']._serialized_end=955
  _globals['_SHOPPINGSERVICE']._serialized_start=958
  _globals['_SHOPPINGSERVICE']._serialized_end=2309
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/universe/quota.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/universe/quota.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65olymp/universe/quota.proto\x12\x0f\x65olymp.universe\"\xa8\t\n\x05Quota\x12\x1d\n\x15permissions_per_space\x18\x06 \x01(\r\x12\x16\n\x0esingle_sing_on\x18\x16 \x01(\x08\x12\x1f\n\x17\x64\x65\x64icated_user_database\x18\x17 \x01(\x08\x12\x1c\n\x14\x61ttributes_per_space\x18\x07 \x01(\r\x12#\n\x1b\x63ustomer_support_reply_time\x18\x18 \x01(\r\x12\x19\n\x11\x61llow_discussions\x18\x1f \x01(\x08\x12\x1e\n\x16\x61\x63hievements_per_space\x18\x0f \x01(\r\x12\x1a\n\x12printers_per_space\x18\x1a \x01(\r\x12%\n\x1d\x65valuations_by_seat_per_month\x18\r \x01(\r\x12!\n\x19priority_evaluation_queue\x18\x19 \x01(\x08\x12\x1b\n\x13plagiarism_analysis\x18\x12 \x01(\x08\x12#\n\x1bsubmission_evaluation_limit\x18\x1b \x01(\r\x12\x19\n\x11members_per_space\x18\x02 \x01(\r\x12\x16\n\x0emember_credits\x18\x1c \x01(\x08\x12\x1c\n\x13\x63\x61mpaigns_per_space\x18\xc8\x01 \x01(\r\x12\x17\n\x0e\x65mails_per_day\x18\xc9\x01 \x01(\r\x12\x19\n\x10\x65mails_per_month\x18\xca\x01 \x01(\r\x12\x1d\n\x15scoreboards_per_space\x18\x05 \x01(\r\x12\x19\n\x11\x63ourses_per_space\x18\x0c \x01(\r\x12\x1a\n\x12problems_per_space\x18\x01 \x01(\r\x12\x19\n\x11tests_per_problem\x18\x65 \x01(\r\x12\x1b\n\x13testset_per_problem\x18\x66 \x01(\r\x12\x1d\n\x15statement_per_problem\x18g \x01(\r\x12\x1d\n\x15\x65\x64itorial_per_problem\x18h \x01(\r\x12\x1d\n\x15solutions_per_problem\x18i \x01(\r\x12\"\n\x1a\x63ode_templates_per_problem\x18j \x01(\r\x12\x17\n\x0f\x64\x65\x62ug_assistant\x18x \x01(\x08\x12#\n\x1b\x64\x65\x62ug_hints_daily_per_admin\x18y \x01(\r\x12$\n\x1c\x64\x65\x62ug_hints_daily_per_member\x18z \x01(\r\x12\x1a\n\x12\x63ontests_per_space\x18\x03 \x01(\r\x12!\n\x19\x61\x63tive_contests_per_space\x18\x04 \x01(\r\x12\x1a\n\x12\x63ontests_per_month\x18\x0e \x01(\r\x12\x1c\n\x14problems_per_contest\x18\n \x01(\r\x12 \n\x18participants_per_contest\x18\x0b \x01(\r\x12\x1c\n\x14\x63ontest_upsolve_mode\x18\x10 \x01(\x08\x12\x1c\n\x14max_contest_duration\x18\x11 \x01(\r\x12\x15\n\rteam_contests\x18\x13 \x01(\x08\x12\x1a\n\x12ghost_participants\x18\x14 \x01(\x08\x12\x1f\n\x17unofficial_participants\x18\x15 \x01(\x08\x42\x33Z1github.com/eolymp/go-sdk/eolymp/universe;universeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.universe.quota_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/universe;universe'
  _globals['_QUOTA']._serialized_start=49
  _globals['_QUOTA']._serialized_end=1241
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.community import penalty_pb2 as _penalty_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreatePenaltyInput(_message.Message):
    __slots__ = ("penalty", "dont_notify")
    PENALTY_FIELD_NUMBER: _ClassVar[int]
    DONT_NOTIFY_FIELD_NUMBER: _ClassVar[int]
    penalty: _penalty_pb2.Penalty
    dont_notify: bool
    def __init__(self, penalty: _Optional[_Union[_penalty_pb2.Penalty, _Mapping]] = ..., dont_notify: bool = ...) -> None: ...

class CreatePenaltyOutput(_message.Message):
    __slots__ = ("penalty_id",)
    PENALTY_ID_FIELD_NUMBER: _ClassVar[int]
    penalty_id: str
    def __init__(self, penalty_id: _Optional[str] = ...) -> None: ...

class UpdatePenaltyInput(_message.Message):
    __slots__ = ("patch", "penalty_id", "penalty")
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        ALL: _ClassVar[UpdatePenaltyInput.Patch]
        SUMMARY: _ClassVar[UpdatePenaltyInput.Patch]
        DESCRIPTION: _ClassVar[UpdatePenaltyInput.Patch]
        SCOPE: _ClassVar[UpdatePenaltyInput.Patch]
        EXPIRES_AT: _ClassVar[UpdatePenaltyInput.Patch]
    ALL: UpdatePenaltyInput.Patch
    SUMMARY: UpdatePenaltyInput.Patch
    DESCRIPTION: UpdatePenaltyInput.Patch
    SCOPE: UpdatePenaltyInput.Patch
    EXPIRES_AT: UpdatePenaltyInput.Patch
    PATCH_FIELD_NUMBER: _ClassVar[int]
    PENALTY_ID_FIELD_NUMBER: _ClassVar[int]
    PENALTY_FIELD_NUMBER: _ClassVar[int]
    patch: _containers.RepeatedScalarFieldContainer[UpdatePenaltyInput.Patch]
    penalty_id: str
    penalty: _penalty_pb2.Penalty
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdatePenaltyInput.Patch, str]]] = ..., penalty_id: _Optional[str] = ..., penalty: _Optional[_Union[_penalty_pb2.Penalty, _Mapping]] = ...) -> None: ...

class UpdatePenaltyOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeletePenaltyInput(_message.Message):
    __slots__ = ("penalty_id",)
    PENALTY_ID_FIELD_NUMBER: _ClassVar[int]
    penalty_id: str
    def __init__(self, penalty_id: _Optional[str] = ...) -> None: ...

class DeletePenaltyOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribePenaltyInput(_message.Message):
    __slots__ = ("penalty_id", "extra")
    PENALTY_ID_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    penalty_id: str
    extra: _containers.RepeatedScalarFieldContainer[_penalty_pb2.Penalty.Extra]
    def __init__(self, penalty_id: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_penalty_pb2.Penalty.Extra, str]]] = ...) -> None: ...

class DescribePenaltyOutput(_message.Message):
    __slots__ = ("penalty",)
    PENALTY_FIELD_NUMBER: _ClassVar[int]
    penalty: _penalty_pb2.Penalty
    def __init__(self, penalty: _Optional[_Union[_penalty_pb2.Penalty, _Mapping]] = ...) -> None: ...

class ListPenaltiesInput(_message.Message):
    __slots__ = ("offset", "size", "extra")
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    offset: int
    size: int
    extra: _containers.RepeatedScalarFieldContainer[_penalty_pb2.Penalty.Extra]
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., extra: _Optional[_Iterable[_Union[_penalty_pb2.Penalty.Extra, str]]] = ...) -> None: ...

class ListPenaltiesOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_penalty_pb2.Penalty]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_penalty_pb2.Penalty, _Mapping]]] = ...) -> None: ...



import datetime

from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Webhook(_message.Message):
    __slots__ = ("id", "name", "secret", "endpoint", "inactive", "events", "created_at", "last_failure_at", "last_success_at", "delivery_count", "failure_count")
    class Event(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_EVENT: _ClassVar[Webhook.Event]
        PROBLEM_CHANGED: _ClassVar[Webhook.Event]
        PROBLEM_STATEMENT_CHANGED: _ClassVar[Webhook.Event]
        PROBLEM_SCORE_CHANGED: _ClassVar[Webhook.Event]
        SUBMISSION_CHANGED: _ClassVar[Webhook.Event]
        SUBMISSION_COMPLETED: _ClassVar[Webhook.Event]
        MEMBER_CHANGED: _ClassVar[Webhook.Event]
        GROUP_CHANGED: _ClassVar[Webhook.Event]
        COURSE_MODULE_CHANGED: _ClassVar[Webhook.Event]
        COURSE_MATERIAL_CHANGED: _ClassVar[Webhook.Event]
        COURSE_STUDENT_CHANGED: _ClassVar[Webhook.Event]
        COURSE_ASSIGNMENT_CHANGED: _ClassVar[Webhook.Event]
        DISCUSSION_MESSAGE_CHANGED: _ClassVar[Webhook.Event]
        POST_CHANGED: _ClassVar[Webhook.Event]
        POST_TRANSLATION_CHANGED: _ClassVar[Webhook.Event]
        POST_PUBLISHED: _ClassVar[Webhook.Event]
        TICKET_CHANGED: _ClassVar[Webhook.Event]
        TICKET_REPLY_CHANGED: _ClassVar[Webhook.Event]
        CONTEST_SUBMISSION_COMPLETED: _ClassVar[Webhook.Event]
        CONTEST_SCORE_CHANGED: _ClassVar[Webhook.Event]
        CONTEST_PARTICIPANT_CHANGED: _ClassVar[Webhook.Event]
        CONTEST_PARTICIPANT_JOINED: _ClassVar[Webhook.Event]
    UNKNOWN_EVENT: Webhook.Event
    PROBLEM_CHANGED: Webhook.Event
    PROBLEM_STATEMENT_CHANGED: Webhook.Event
    PROBLEM_SCORE_CHANGED: Webhook.Event
    SUBMISSION_CHANGED: Webhook.Event
    SUBMISSION_COMPLETED: Webhook.Event
    MEMBER_CHANGED: Webhook.Event
    GROUP_CHANGED: Webhook.Event
    COURSE_MODULE_CHANGED: Webhook.Event
    COURSE_MATERIAL_CHANGED: Webhook.Event
    COURSE_STUDENT_CHANGED: Webhook.Event
    COURSE_ASSIGNMENT_CHANGED: Webhook.Event
    DISCUSSION_MESSAGE_CHANGED: Webhook.Event
    POST_CHANGED: Webhook.Event
    POST_TRANSLATION_CHANGED: Webhook.Event
    POST_PUBLISHED: Webhook.Event
    TICKET_CHANGED: Webhook.Event
    TICKET_REPLY_CHANGED: Webhook.Event
    CONTEST_SUBMISSION_COMPLETED: Webhook.Event
    CONTEST_SCORE_CHANGED: Webhook.Event
    CONTEST_PARTICIPANT_CHANGED: Webhook.Event
    CONTEST_PARTICIPANT_JOINED: Webhook.Event
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        PATCH_UNKNOWN: _ClassVar[Webhook.Patch]
        PATCH_ALL: _ClassVar[Webhook.Patch]
        PATCH_NAME: _ClassVar[Webhook.Patch]
        PATCH_ENDPOINT: _ClassVar[Webhook.Patch]
        PATCH_INACTIVE: _ClassVar[Webhook.Patch]
        PATCH_EVENTS: _ClassVar[Webhook.Patch]
    PATCH_UNKNOWN: Webhook.Patch
    PATCH_ALL: Webhook.Patch
    PATCH_NAME: Webhook.Patch
    PATCH_ENDPOINT: Webhook.Patch
    PATCH_INACTIVE: Webhook.Patch
    PATCH_EVENTS: Webhook.Patch
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    SECRET_FIELD_NUMBER: _ClassVar[int]
    ENDPOINT_FIELD_NUMBER: _ClassVar[int]
    INACTIVE_FIELD_NUMBER: _ClassVar[int]
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    LAST_FAILURE_AT_FIELD_NUMBER: _ClassVar[int]
    LAST_SUCCESS_AT_FIELD_NUMBER: _ClassVar[int]
    DELIVERY_COUNT_FIELD_NUMBER: _ClassVar[int]
    FAILURE_COUNT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    secret: str
    endpoint: str
    inactive: bool
    events: _containers.RepeatedScalarFieldContainer[Webhook.Event]
    created_at: _timestamp_pb2.Timestamp
    last_failure_at: _timestamp_pb2.Timestamp
    last_success_at: _timestamp_pb2.Timestamp
    delivery_count: int
    failure_count: int
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., secret: _Optional[str] = ..., endpoint: _Optional[str] = ..., inactive: bool = ..., events: _Optional[_Iterable[_Union[Webhook.Event, str]]] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., last_failure_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., last_success_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., delivery_count: _Optional[int] = ..., failure_count: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/course/class_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/course/class_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.course import assignment_pb2 as eolymp_dot_course_dot_assignment__pb2
from eolymp.course import class_pb2 as eolymp_dot_course_dot_class__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!eolymp/course/class_service.proto\x12\reolymp.course\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1e\x65olymp/course/assignment.proto\x1a\x19\x65olymp/course/class.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"7\n\x10\x43reateClassInput\x12#\n\x05\x63lass\x18\x01 \x01(\x0b\x32\x14.eolymp.course.Class\"%\n\x11\x43reateClassOutput\x12\x10\n\x08\x63lass_id\x18\x02 \x01(\t\"\xaf\x01\n\x10UpdateClassInput\x12\x34\n\x05patch\x18\x01 \x03(\x0e\x32%.eolymp.course.UpdateClassInput.Patch\x12\x10\n\x08group_id\x18\x02 \x01(\t\x12#\n\x05\x63lass\x18\x03 \x01(\x0b\x32\x14.eolymp.course.Class\".\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x0c\n\x08INACTIVE\x10\x01\x12\x0e\n\nASSIGN_ALL\x10\x02\"\x13\n\x11UpdateClassOutput\"$\n\x10\x44\x65leteClassInput\x12\x10\n\x08group_id\x18\x01 \x01(\t\"\x13\n\x11\x44\x65leteClassOutput\"&\n\x12\x44\x65scribeClassInput\x12\x10\n\x08group_id\x18\x01 \x01(\t\":\n\x13\x44\x65scribeClassOutput\x12#\n\x05\x63lass\x18\x01 \x01(\x0b\x32\x14.eolymp.course.Class\"\x92\x03\n\x10ListClassesInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0e\n\x06search\x18\x14 \x01(\t\x12\x37\n\x07\x66ilters\x18( \x01(\x0b\x32&.eolymp.course.ListClassesInput.Filter\x12\x36\n\x04sort\x18\x32 \x01(\x0e\x32(.eolymp.course.ListClassesInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x1a\x99\x01\n\x06\x46ilter\x12*\n\x02id\x18\n \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x08group_id\x18\x0b \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tmember_id\x18\x0c \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"\x17\n\x08Sortable\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\"G\n\x11ListClassesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12#\n\x05items\x18\x02 \x03(\x0b\x32\x14.eolymp.course.Class\"\x86\x02\n\x19ListClassAssignmentsInput\x12\x10\n\x08group_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0e\n\x06search\x18\x14 \x01(\t\x12@\n\x07\x66ilters\x18( \x01(\x0b\x32/.eolymp.course.ListClassAssignmentsInput.Filter\x1ag\n\x06\x46ilter\x12*\n\x02id\x18\n \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tmodule_id\x18\x0b \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"U\n\x1aListClassAssignmentsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.course.Assignment\"\xca\x01\n\x1aUpdateClassAssignmentInput\x12\x10\n\x08group_id\x18\x01 \x01(\t\x12\x11\n\tmodule_id\x18\x02 \x01(\t\x12/\n\x0bstart_after\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x0f\x63omplete_before\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08\x64uration\x18\r \x01(\r\x12\x0f\n\x07upsolve\x18\x1e \x01(\x08\"\x1d\n\x1bUpdateClassAssignmentOutput\"A\n\x1a\x44\x65leteClassAssignmentInput\x12\x10\n\x08group_id\x18\x01 \x01(\t\x12\x11\n\tmodule_id\x18\x02 \x01(\t\"\x1d\n\x1b\x44\x65leteClassAssignmentOutput2\xc4\n\n\x0c\x43lassService\x12\x8c\x01\n\x0b\x43reateClass\x12\x1f.eolymp.course.CreateClassInput\x1a .eolymp.course.CreateClassOutput\":\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\x82\xd3\xe4\x93\x02\n\"\x08/classes\x12\x97\x01\n\x0bUpdateClass\x12\x1f.eolymp.course.UpdateClassInput\x1a .eolymp.course.UpdateClassOutput\"E\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\x82\xd3\xe4\x93\x02\x15\"\x13/classes/{group_id}\x12\x97\x01\n\x0b\x44\x65leteClass\x12\x1f.eolymp.course.DeleteClassInput\x1a .eolymp.course.DeleteClassOutput\"E\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\x82\xd3\xe4\x93\x02\x15*\x13/classes/{group_id}\x12\x9c\x01\n\rDescribeClass\x12!.eolymp.course.DescribeClassInput\x1a\".eolymp.course.DescribeClassOutput\"D\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\x82\xd3\xe4\x93\x02\x15\x12\x13/classes/{group_id}\x12\x8b\x01\n\x0bListClasses\x12\x1f.eolymp.course.ListClassesInput\x1a .eolymp.course.ListClassesOutput\"9\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\x82\xd3\xe4\x93\x02\n\x12\x08/classes\x12\xbd\x01\n\x14ListClassAssignments\x12(.eolymp.course.ListClassAssignmentsInput\x1a).eolymp.course.ListClassAssignmentsOutput\"P\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\x82\xd3\xe4\x93\x02!\x12\x1f/classes/{group_id}/assignments\x12\xc0\x01\n\x15UpdateClassAssignment\x12).eolymp.course.UpdateClassAssignmentInput\x1a*.eolymp.course.UpdateClassAssignmentOutput\"P\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\x82\xd3\xe4\x93\x02!\"\x1f/classes/{group_id}/assignments\x12\xc0\x01\n\x15\x44\x65leteClassAssignment\x12).eolymp.course.DeleteClassAssignmentInput\x1a*.eolymp.course.DeleteClassAssignmentOutput\"P\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\x82\xd3\xe4\x93\x02!*\x1f/classes/{group_id}/assignmentsB/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.class_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _globals['_CLASSSERVICE'].methods_by_name['CreateClass']._loaded_options = None
  _globals['_CLASSSERVICE'].methods_by_name['CreateClass']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\027\212\343\n\023course:course:write\202\323\344\223\002\n\"\010/classes'
  _globals['_CLASSSERVICE'].methods_by_name['UpdateClass']._loaded_options = None
  _globals['_CLASSSERVICE'].methods_by_name['UpdateClass']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\027\212\343\n\023course:course:write\202\323\344\223\002\025\"\023/classes/{group_id}'
  _globals['_CLASSSERVICE'].methods_by_name['DeleteClass']._loaded_options = None
  _globals['_CLASSSERVICE'].methods_by_name['DeleteClass']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023course:course:write\202\323\344\223\002\025*\023/classes/{group_id}'
  _globals['_CLASSSERVICE'].methods_by_name['DescribeClass']._loaded_options = None
  _globals['_CLASSSERVICE'].methods_by_name['DescribeClass']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022course:course:read\202\323\344\223\002\025\022\023/classes/{group_id}'
  _globals['_CLASSSERVICE'].methods_by_name['ListClasses']._loaded_options = None
  _globals['_CLASSSERVICE'].methods_by_name['ListClasses']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022course:course:read\202\323\344\223\002\n\022\010/classes'
  _globals['_CLASSSERVICE'].methods_by_name['ListClassAssignments']._loaded_options = None
  _globals['_CLASSSERVICE'].methods_by_name['ListClassAssignments']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022course:course:read\202\323\344\223\002!\022\037/classes/{group_id}/assignments'
  _globals['_CLASSSERVICE'].methods_by_name['UpdateClassAssignment']._loaded_options = None
  _globals['_CLASSSERVICE'].methods_by_name['UpdateClassAssignment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022course:course:read\202\323\344\223\002!\"\037/classes/{group_id}/assignments'
  _globals['_CLASSSERVICE'].methods_by_name['DeleteClassAssignment']._loaded_options = None
  _globals['_CLASSSERVICE'].methods_by_name['DeleteClassAssignment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022course:course:read\202\323\344\223\002!*\037/classes/{group_id}/assignments'
  _globals['_CREATECLASSINPUT']._serialized_start=312
  _globals['_CREATECLASSINPUT']._serialized_end=367
  _globals['_CREATECLASSOUTPUT']._serialized_start=369
  _globals['_CREATECLASSOUTPUT']._serialized_end=406
  _globals['_UPDATECLASSINPUT']._serialized_start=409
  _globals['_UPDATECLASSINPUT']._serialized_end=584
  _globals['_UPDATECLASSINPUT_PATCH']._serialized_start=538
  _globals['_UPDATECLASSINPUT_PATCH']._serialized_end=584
  _globals['_UPDATECLASSOUTPUT']._serialized_start=586
  _globals['_UPDATECLASSOUTPUT']._serialized_end=605
  _globals['_DELETECLASSINPUT']._serialized_start=607
  _globals['_DELETECLASSINPUT']._serialized_end=643
  _globals['_DELETECLASSOUTPUT']._serialized_start=645
  _globals['_DELETECLASSOUTPUT']._serialized_end=664
  _globals['_DESCRIBECLASSINPUT']._serialized_start=666
  _globals['_DESCRIBECLASSINPUT']._serialized_end=704
  _globals['_DESCRIBECLASSOUTPUT']._serialized_start=706
  _globals['_DESCRIBECLASSOUTPUT']._serialized_end=764
  _globals['_LISTCLASSESINPUT']._serialized_start=767
  _globals['_LISTCLASSESINPUT']._serialized_end=1169
  _globals['_LISTCLASSESINPUT_FILTER']._serialized_start=991
  _globals['_LISTCLASSESINPUT_FILTER']._serialized_end=1144
  _globals['_LISTCLASSESINPUT_SORTABLE']._serialized_start=1146
  _globals['_LISTCLASSESINPUT_SORTABLE']._serialized_end=1169
  _globals['_LISTCLASSESOUTPUT']._serialized_start=1171
  _globals['_LISTCLASSESOUTPUT']._serialized_end=1242
  _globals['_LISTCLASSASSIGNMENTSINPUT']._serialized_start=1245
  _globals['_LISTCLASSASSIGNMENTSINPUT']._serialized_end=1507
  _globals['_LISTCLASSASSIGNMENTSINPUT_FILTER']._serialized_start=1404
  _globals['_LISTCLASSASSIGNMENTSINPUT_FILTER']._serialized_end=1507
  _globals['_LISTCLASSASSIGNMENTSOUTPUT']._serialized_start=1509
  _globals['_LISTCLASSASSIGNMENTSOUTPUT']._serialized_end=1594
  _globals['_UPDATECLASSASSIGNMENTINPUT']._serialized_start=1597
  _globals['_UPDATECLASSASSIGNMENTINPUT']._serialized_end=1799
  _globals['_UPDATECLASSASSIGNMENTOUTPUT']._serialized_start=1801
  _globals['_UPDATECLASSASSIGNMENTOUTPUT']._serialized_end=1830
  _globals['_DELETECLASSASSIGNMENTINPUT']._serialized_start=1832
  _globals['_DELETECLASSASSIGNMENTINPUT']._serialized_end=1897
  _globals['_DELETECLASSASSIGNMENTOUTPUT']._serialized_start=1899
  _globals['_DELETECLASSASSIGNMENTOUTPUT']._serialized_end=1928
  _globals['_CLASSSERVICE']._serialized_start=1931
  _globals['_CLASSSERVICE']._serialized_end=3279
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/ranker/format.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/ranker/format.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/ranker/format.proto\x12\reolymp.ranker*%\n\x06\x46ormat\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03IOI\x10\x01\x12\x08\n\x04ICPC\x10\x02\x42/Z-github.com/eolymp/go-sdk/eolymp/ranker;rankerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.ranker.format_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/ranker;ranker'
  _globals['_FORMAT']._serialized_start=45
  _globals['_FORMAT']._serialized_end=82
# @@protoc_insertion_point(module_scope)



import datetime

from eolymp.atlas import testing_feedback_pb2 as _testing_feedback_pb2
from eolymp.atlas import testing_scoring_pb2 as _testing_scoring_pb2
from eolymp.executor import stats_pb2 as _stats_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Submission(_message.Message):
    __slots__ = ("id", "problem_id", "version", "user_id", "member_id", "submitted_at", "judged_at", "lang", "source", "source_url", "signature", "status", "verdict", "error", "error_url", "cost", "score", "percentage", "time_usage", "cpu_usage", "memory_usage", "resource_usage", "groups", "assistant_available", "cursor")
    class Extra(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        NO_EXTRA: _ClassVar[Submission.Extra]
        GROUPS: _ClassVar[Submission.Extra]
        RUNS: _ClassVar[Submission.Extra]
    NO_EXTRA: Submission.Extra
    GROUPS: Submission.Extra
    RUNS: Submission.Extra
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        NONE: _ClassVar[Submission.Status]
        PENDING: _ClassVar[Submission.Status]
        PROVISIONING: _ClassVar[Submission.Status]
        INITIALIZING: _ClassVar[Submission.Status]
        TESTING: _ClassVar[Submission.Status]
        TIMEOUT: _ClassVar[Submission.Status]
        COMPLETE: _ClassVar[Submission.Status]
        ERROR: _ClassVar[Submission.Status]
        FAILURE: _ClassVar[Submission.Status]
        SKIPPED: _ClassVar[Submission.Status]
        BLOCKED: _ClassVar[Submission.Status]
    NONE: Submission.Status
    PENDING: Submission.Status
    PROVISIONING: Submission.Status
    INITIALIZING: Submission.Status
    TESTING: Submission.Status
    TIMEOUT: Submission.Status
    COMPLETE: Submission.Status
    ERROR: Submission.Status
    FAILURE: Submission.Status
    SKIPPED: Submission.Status
    BLOCKED: Submission.Status
    class Verdict(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        NO_VERDICT: _ClassVar[Submission.Verdict]
        ACCEPTED: _ClassVar[Submission.Verdict]
        WRONG_ANSWER: _ClassVar[Submission.Verdict]
        TIME_LIMIT_EXCEEDED: _ClassVar[Submission.Verdict]
        CPU_EXHAUSTED: _ClassVar[Submission.Verdict]
        MEMORY_OVERFLOW: _ClassVar[Submission.Verdict]
        RUNTIME_ERROR: _ClassVar[Submission.Verdict]
    NO_VERDICT: Submission.Verdict
    ACCEPTED: Submission.Verdict
    WRONG_ANSWER: Submission.Verdict
    TIME_LIMIT_EXCEEDED: Submission.Verdict
    CPU_EXHAUSTED: Submission.Verdict
    MEMORY_OVERFLOW: Submission.Verdict
    RUNTIME_ERROR: Submission.Verdict
    class Run(_message.Message):
        __slots__ = ("id", "index", "time_usage", "cpu_usage", "memory_usage", "resource_usage", "input_url", "output_url", "answer_url", "cost", "score", "status", "verdict", "debug_stats", "checker_stats", "interactor_stats")
        ID_FIELD_NUMBER: _ClassVar[int]
        INDEX_FIELD_NUMBER: _ClassVar[int]
        TIME_USAGE_FIELD_NUMBER: _ClassVar[int]
        CPU_USAGE_FIELD_NUMBER: _ClassVar[int]
        MEMORY_USAGE_FIELD_NUMBER: _ClassVar[int]
        RESOURCE_USAGE_FIELD_NUMBER: _ClassVar[int]
        INPUT_URL_FIELD_NUMBER: _ClassVar[int]
        OUTPUT_URL_FIELD_NUMBER: _ClassVar[int]
        ANSWER_URL_FIELD_NUMBER: _ClassVar[int]
        COST_FIELD_NUMBER: _ClassVar[int]
        SCORE_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        VERDICT_FIELD_NUMBER: _ClassVar[int]
        DEBUG_STATS_FIELD_NUMBER: _ClassVar[int]
        CHECKER_STATS_FIELD_NUMBER: _ClassVar[int]
        INTERACTOR_STATS_FIELD_NUMBER: _ClassVar[int]
        id: str
        index: int
        time_usage: int
        cpu_usage: int
        memory_usage: int
        resource_usage: float
        input_url: str
        output_url: str
        answer_url: str
        cost: float
        score: float
        status: Submission.Status
        verdict: Submission.Verdict
        debug_stats: _stats_pb2.Stats
        checker_stats: _stats_pb2.Stats
        interactor_stats: _stats_pb2.Stats
        def __init__(self, id: _Optional[str] = ..., index: _Optional[int] = ..., time_usage: _Optional[int] = ..., cpu_usage: _Optional[int] = ..., memory_usage: _Optional[int] = ..., resource_usage: _Optional[float] = ..., input_url: _Optional[str] = ..., output_url: _Optional[str] = ..., answer_url: _Optional[str] = ..., cost: _Optional[float] = ..., score: _Optional[float] = ..., status: _Optional[_Union[Submission.Status, str]] = ..., verdict: _Optional[_Union[Submission.Verdict, str]] = ..., debug_stats: _Optional[_Union[_stats_pb2.Stats, _Mapping]] = ..., checker_stats: _Optional[_Union[_stats_pb2.Stats, _Mapping]] = ..., interactor_stats: _Optional[_Union[_stats_pb2.Stats, _Mapping]] = ...) -> None: ...
    class Group(_message.Message):
        __slots__ = ("index", "status", "verdict", "dependencies", "cost", "score", "scoring_mode", "feedback_policy", "time_usage", "cpu_usage", "memory_usage", "resource_usage", "runs")
        INDEX_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        VERDICT_FIELD_NUMBER: _ClassVar[int]
        DEPENDENCIES_FIELD_NUMBER: _ClassVar[int]
        COST_FIELD_NUMBER: _ClassVar[int]
        SCORE_FIELD_NUMBER: _ClassVar[int]
        SCORING_MODE_FIELD_NUMBER: _ClassVar[int]
        FEEDBACK_POLICY_FIELD_NUMBER: _ClassVar[int]
        TIME_USAGE_FIELD_NUMBER: _ClassVar[int]
        CPU_USAGE_FIELD_NUMBER: _ClassVar[int]
        MEMORY_USAGE_FIELD_NUMBER: _ClassVar[int]
        RESOURCE_USAGE_FIELD_NUMBER: _ClassVar[int]
        RUNS_FIELD_NUMBER: _ClassVar[int]
        index: int
        status: Submission.Status
        verdict: Submission.Verdict
        dependencies: _containers.RepeatedScalarFieldContainer[int]
        cost: float
        score: float
        scoring_mode: _testing_scoring_pb2.ScoringMode
        feedback_policy: _testing_feedback_pb2.FeedbackPolicy
        time_usage: int
        cpu_usage: int
        memory_usage: int
        resource_usage: float
        runs: _containers.RepeatedCompositeFieldContainer[Submission.Run]
        def __init__(self, index: _Optional[int] = ..., status: _Optional[_Union[Submission.Status, str]] = ..., verdict: _Optional[_Union[Submission.Verdict, str]] = ..., dependencies: _Optional[_Iterable[int]] = ..., cost: _Optional[float] = ..., score: _Optional[float] = ..., scoring_mode: _Optional[_Union[_testing_scoring_pb2.ScoringMode, str]] = ..., feedback_policy: _Optional[_Union[_testing_feedback_pb2.FeedbackPolicy, str]] = ..., time_usage: _Optional[int] = ..., cpu_usage: _Optional[int] = ..., memory_usage: _Optional[int] = ..., resource_usage: _Optional[float] = ..., runs: _Optional[_Iterable[_Union[Submission.Run, _Mapping]]] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    SUBMITTED_AT_FIELD_NUMBER: _ClassVar[int]
    JUDGED_AT_FIELD_NUMBER: _ClassVar[int]
    LANG_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    SOURCE_URL_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    VERDICT_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    ERROR_URL_FIELD_NUMBER: _ClassVar[int]
    COST_FIELD_NUMBER: _ClassVar[int]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    TIME_USAGE_FIELD_NUMBER: _ClassVar[int]
    CPU_USAGE_FIELD_NUMBER: _ClassVar[int]
    MEMORY_USAGE_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_USAGE_FIELD_NUMBER: _ClassVar[int]
    GROUPS_FIELD_NUMBER: _ClassVar[int]
    ASSISTANT_AVAILABLE_FIELD_NUMBER: _ClassVar[int]
    CURSOR_FIELD_NUMBER: _ClassVar[int]
    id: str
    problem_id: str
    version: int
    user_id: str
    member_id: str
    submitted_at: _timestamp_pb2.Timestamp
    judged_at: _timestamp_pb2.Timestamp
    lang: str
    source: str
    source_url: str
    signature: str
    status: Submission.Status
    verdict: Submission.Verdict
    error: str
    error_url: str
    cost: float
    score: float
    percentage: float
    time_usage: int
    cpu_usage: int
    memory_usage: int
    resource_usage: float
    groups: _containers.RepeatedCompositeFieldContainer[Submission.Group]
    assistant_available: bool
    cursor: str
    def __init__(self, id: _Optional[str] = ..., problem_id: _Optional[str] = ..., version: _Optional[int] = ..., user_id: _Optional[str] = ..., member_id: _Optional[str] = ..., submitted_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., judged_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., lang: _Optional[str] = ..., source: _Optional[str] = ..., source_url: _Optional[str] = ..., signature: _Optional[str] = ..., status: _Optional[_Union[Submission.Status, str]] = ..., verdict: _Optional[_Union[Submission.Verdict, str]] = ..., error: _Optional[str] = ..., error_url: _Optional[str] = ..., cost: _Optional[float] = ..., score: _Optional[float] = ..., percentage: _Optional[float] = ..., time_usage: _Optional[int] = ..., cpu_usage: _Optional[int] = ..., memory_usage: _Optional[int] = ..., resource_usage: _Optional[float] = ..., groups: _Optional[_Iterable[_Union[Submission.Group, _Mapping]]] = ..., assistant_available: bool = ..., cursor: _Optional[str] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.certificate import certificate_pb2 as _certificate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateCertificateInput(_message.Message):
    __slots__ = ("certificate",)
    CERTIFICATE_FIELD_NUMBER: _ClassVar[int]
    certificate: _certificate_pb2.Certificate
    def __init__(self, certificate: _Optional[_Union[_certificate_pb2.Certificate, _Mapping]] = ...) -> None: ...

class CreateCertificateOutput(_message.Message):
    __slots__ = ("certificate_id", "download_url")
    CERTIFICATE_ID_FIELD_NUMBER: _ClassVar[int]
    DOWNLOAD_URL_FIELD_NUMBER: _ClassVar[int]
    certificate_id: str
    download_url: str
    def __init__(self, certificate_id: _Optional[str] = ..., download_url: _Optional[str] = ...) -> None: ...

class VoidCertificateInput(_message.Message):
    __slots__ = ("certificate_id",)
    CERTIFICATE_ID_FIELD_NUMBER: _ClassVar[int]
    certificate_id: str
    def __init__(self, certificate_id: _Optional[str] = ...) -> None: ...

class VoidCertificateOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeCertificateInput(_message.Message):
    __slots__ = ("certificate_id",)
    CERTIFICATE_ID_FIELD_NUMBER: _ClassVar[int]
    certificate_id: str
    def __init__(self, certificate_id: _Optional[str] = ...) -> None: ...

class DescribeCertificateOutput(_message.Message):
    __slots__ = ("certificate",)
    CERTIFICATE_FIELD_NUMBER: _ClassVar[int]
    certificate: _certificate_pb2.Certificate
    def __init__(self, certificate: _Optional[_Union[_certificate_pb2.Certificate, _Mapping]] = ...) -> None: ...

class ListCertificatesInput(_message.Message):
    __slots__ = ("offset", "size", "member_id")
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    offset: int
    size: int
    member_id: str
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., member_id: _Optional[str] = ...) -> None: ...

class ListCertificatesOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_certificate_pb2.Certificate]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_certificate_pb2.Certificate, _Mapping]]] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.commerce import product_pb2 as _product_pb2
from eolymp.wellknown import direction_pb2 as _direction_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateProductInput(_message.Message):
    __slots__ = ("product",)
    PRODUCT_FIELD_NUMBER: _ClassVar[int]
    product: _product_pb2.Product
    def __init__(self, product: _Optional[_Union[_product_pb2.Product, _Mapping]] = ...) -> None: ...

class CreateProductOutput(_message.Message):
    __slots__ = ("product_id",)
    PRODUCT_ID_FIELD_NUMBER: _ClassVar[int]
    product_id: str
    def __init__(self, product_id: _Optional[str] = ...) -> None: ...

class UpdateProductInput(_message.Message):
    __slots__ = ("patch", "product_id", "product")
    PATCH_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_ID_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_FIELD_NUMBER: _ClassVar[int]
    patch: _containers.RepeatedScalarFieldContainer[_product_pb2.Product.Patch.Field]
    product_id: str
    product: _product_pb2.Product
    def __init__(self, patch: _Optional[_Iterable[_Union[_product_pb2.Product.Patch.Field, str]]] = ..., product_id: _Optional[str] = ..., product: _Optional[_Union[_product_pb2.Product, _Mapping]] = ...) -> None: ...

class UpdateProductOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteProductInput(_message.Message):
    __slots__ = ("product_id",)
    PRODUCT_ID_FIELD_NUMBER: _ClassVar[int]
    product_id: str
    def __init__(self, product_id: _Optional[str] = ...) -> None: ...

class DeleteProductOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeProductInput(_message.Message):
    __slots__ = ("product_id", "locale", "extra")
    PRODUCT_ID_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    product_id: str
    locale: str
    extra: _containers.RepeatedScalarFieldContainer[_product_pb2.Product.Extra.Field]
    def __init__(self, product_id: _Optional[str] = ..., locale: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_product_pb2.Product.Extra.Field, str]]] = ...) -> None: ...

class DescribeProductOutput(_message.Message):
    __slots__ = ("product",)
    PRODUCT_FIELD_NUMBER: _ClassVar[int]
    product: _product_pb2.Product
    def __init__(self, product: _Optional[_Union[_product_pb2.Product, _Mapping]] = ...) -> None: ...

class ListProductsInput(_message.Message):
    __slots__ = ("offset", "size", "search", "filters", "sort", "order", "locale", "extra")
    class Sortable(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        DEFAULT: _ClassVar[ListProductsInput.Sortable]
    DEFAULT: ListProductsInput.Sortable
    class Filter(_message.Message):
        __slots__ = ("id", "name", "out_of_stock", "price")
        ID_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        OUT_OF_STOCK_FIELD_NUMBER: _ClassVar[int]
        PRICE_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        name: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        out_of_stock: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        price: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionInt]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., name: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., out_of_stock: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ..., price: _Optional[_Iterable[_Union[_expression_pb2.ExpressionInt, _Mapping]]] = ...) -> None: ...
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    SEARCH_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    SORT_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    offset: int
    size: int
    search: str
    filters: ListProductsInput.Filter
    sort: ListProductsInput.Sortable
    order: _direction_pb2.Direction
    locale: str
    extra: _containers.RepeatedScalarFieldContainer[_product_pb2.Product.Extra.Field]
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., search: _Optional[str] = ..., filters: _Optional[_Union[ListProductsInput.Filter, _Mapping]] = ..., sort: _Optional[_Union[ListProductsInput.Sortable, str]] = ..., order: _Optional[_Union[_direction_pb2.Direction, str]] = ..., locale: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_product_pb2.Product.Extra.Field, str]]] = ...) -> None: ...

class ListProductsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_product_pb2.Product]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_product_pb2.Product, _Mapping]]] = ...) -> None: ...
